==> QMK-Groundstation-v0.0.5.tar.gz: QMK-Groundstation-v0.0.5/Forms/mktool.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Manuel Schrape                                  *
 *   manuel.schrape@gmx.de                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License.        *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef MKTOOL_H
#define MKTOOL_H

#include <QMainWindow>
#include <QSettings>

#include "ui_mktool.h"

#include "SerialPort/ManageSerialPort.h"

class QextSerialPort;

class MKTool : public QMainWindow, public Ui::dlg_mktool_UI
{
      Q_OBJECT

public:
      MKTool();
      ~MKTool();

private:

    ManageSerialPort *serialPort;
    QByteArray allDataReceived;
    QString RXS;

    int AnalogData[32];
    int DecodeData[100];

    bool check_CRC(QString RXString);
    void rx_NewData(QString RX_Data);
    void show_Data();
    void read_Settings();
    void write_Settings();

//protected:

private slots:
    void slot_newDataReceived(const QByteArray &dataReceived);
    void slot_OpenPort();
    void slot_Quit();
    void Decode64();
};

#endif

==> QMK-Groundstation-v0.2.1.tar.gz: QMK-Groundstation-v0.2.1/Forms/mktool.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Manuel Schrape                                  *
 *   manuel.schrape@gmx.de                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License.        *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef MKTOOL_H
#define MKTOOL_H

#include <QMainWindow>
#include <QSettings>
#include <QString>
#include <QTimer>
#include <QComboBox>

#include "ui_mktool.h"

#include "SerialPort/ManageSerialPort.h"

class QextSerialPort;

class MKTool : public QMainWindow, public Ui::dlg_mktool_UI
{
      Q_OBJECT

public:
      MKTool();
      ~MKTool();

private:

    ManageSerialPort *serialPort;
    QByteArray allDataReceived;
    QString RXS;
    QString LastSend;
    QTimer* timer;

    QComboBox *setCombo(QComboBox *Combo, int Set, int Wert);
    int get_Value(QComboBox *Combo);

    int AnalogData[32];
    int DecodeData[150];
    char TX_Data[150];

    int ParameterSet[6][150];

    bool check_CRC(QString RXString);
    QString add_CRC(QString TXString);

    void send_Data(char CMD, char Data[150],unsigned int Length);
    void new_RXData(QString RX_Data);

    void show_DebugData();
    void show_ParameterSet(int Set);
    void store_ParameterSet(int Set);

    void read_Settings();
    void write_Settings();

    QString Encode64(char Data[150],unsigned int Length);
    void Decode64(QString Data, bool Long = false);

    void set_LED(QToolButton *ToolButton, bool On=false);

//protected:

private slots:
    void slot_newDataReceived(const QByteArray &dataReceived);
    void slot_OpenPort();
    void slot_Quit();
    void slot_Timer();

    void slot_tbUp();
    void slot_tbDown();
    void slot_tbLeft();
    void slot_tbRight();
    void slot_LEDtoValue();
    void slot_ValuetoLED16(int Wert);
    void slot_ValuetoLED17(int Wert);

    void slot_GetParameter();
    void slot_SetParameter();

    void slot_Send();
};

#endif
